"""

  clpaws.py - utility to operate on the AWS for CLUSTERPRO X.

DESCRIPTION:
    This is the entry point of clpaws command line tools.

"""

import sys

import clpaws.errors as error
from clpaws.azmon import main as azmon
from clpaws.dnsctl import main as dnsctl
from clpaws.eipctl import main as eipctl
from clpaws.enichk import main as enichk
from clpaws.vipctl import main as vipctl


def usage():
    """Show usage."""
    print('''
usage: clpaws <command> [parameters]

[Command List}
 * azmon
 * eipctl
 * enichk
 * vipctl
 * dnsctl
''')
    return error.ERRORNO['argument_error']


def main():
    """Main routine."""
    commands = dict(azmon=azmon,
                    eipctl=eipctl,
                    enichk=enichk,
                    vipctl=vipctl,
                    dnsctl=dnsctl)

    sys.argv = sys.argv[1:]   # remove the first argument.

    if len(sys.argv) > 0 and sys.argv[0] in commands:
        return commands[sys.argv[0]]()
    else:
        return usage()


if __name__ == '__main__':
    sys.exit(main())
